<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>LXQtTaskBar</name>
    <message>
        <location filename="../../../lxqttaskbar.cpp" line="644"/>
        <source>Activate task %1</source>
        <translation>Attiva applicazione %1</translation>
    </message>
</context>
<context>
    <name>LXQtTaskButton</name>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="514"/>
        <source>Application</source>
        <translation>Applicazione</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="548"/>
        <source>To &amp;Desktop</source>
        <translation>Al &amp;desktop</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="550"/>
        <source>&amp;All Desktops</source>
        <translation>&amp;Tutti i desktop</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="558"/>
        <source>Desktop &amp;%1</source>
        <translation>Desktop &amp;%1</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="565"/>
        <source>&amp;To Current Desktop</source>
        <translation>&amp;Al desktop corrente</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="573"/>
        <source>&amp;Move</source>
        <translation>&amp;Sposta</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="576"/>
        <source>Resi&amp;ze</source>
        <translation>&amp;Ridimensiona</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="583"/>
        <source>Ma&amp;ximize</source>
        <translation>Ma&amp;ssimizza</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="590"/>
        <source>Maximize vertically</source>
        <translation>Massimizza verticalmente</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="595"/>
        <source>Maximize horizontally</source>
        <translation>Massimizza orizzontalmente</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="601"/>
        <source>&amp;Restore</source>
        <translation>&amp;Ripristina</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="605"/>
        <source>Mi&amp;nimize</source>
        <translation>Mi&amp;nimizza</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="611"/>
        <source>Roll down</source>
        <translation>Srotola</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="617"/>
        <source>Roll up</source>
        <translation>Arrotola</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="625"/>
        <source>&amp;Layer</source>
        <translation>&amp;Livello</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="627"/>
        <source>Always on &amp;top</source>
        <translation>Sempre in &amp;primo piano</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="633"/>
        <source>&amp;Normal</source>
        <translation>&amp;Normale</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="639"/>
        <source>Always on &amp;bottom</source>
        <translation>Sempre in &amp;secondo piano</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="647"/>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
</context>
<context>
    <name>LXQtTaskGroup</name>
    <message>
        <location filename="../../../lxqttaskgroup.cpp" line="83"/>
        <source>Group</source>
        <translation>Gruppo</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskgroup.cpp" line="85"/>
        <source>Close group</source>
        <translation>Chiudi gruppo</translation>
    </message>
</context>
<context>
    <name>LXQtTaskbarConfiguration</name>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="14"/>
        <source>Task Manager Settings</source>
        <translation>Impostazioni della barra applicazioni</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="43"/>
        <source>Show only windows from desktop</source>
        <translation>Mostra solo finestre del desktop</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="55"/>
        <source>Show only windows from &amp;panel&apos;s screen</source>
        <translation>Mostra solo finestre dello &amp;schermo del pannello</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="62"/>
        <source>Show only minimized windows</source>
        <translation>Mostra solo finestre minimizzate</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="69"/>
        <source>Raise minimized windows on current desktop</source>
        <translation>Alza finestre minimizzate sul desktop attuale</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="83"/>
        <source>Cycle windows on wheel scrolling</source>
        <translation>Scorri le finestre con la rotellina</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="93"/>
        <source>Window &amp;grouping</source>
        <translation>&amp;Raggruppa finestre della stessa applicazione</translation>
    </message>
    <message>
        <source>Show popup on mouse hover </source>
        <translation type="vanished">Mostra popup al passaggio del puntatore </translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="112"/>
        <source>Appearance</source>
        <translation>Aspetto</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="131"/>
        <source>Maximum button width</source>
        <translation>Larghezza massima del pulsante</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="144"/>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="170"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="157"/>
        <source>Maximum button height</source>
        <translation>Altezza massima del pulsante</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="190"/>
        <source>Use icons by WindowClass, if available</source>
        <translation>Usa icone della classe della finestra se disponibile</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="183"/>
        <source>Auto&amp;rotate buttons when the panel is vertical</source>
        <translation>Ruota &amp;automaticamente se il panello è verticale</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="102"/>
        <source>Show popup on mouse hover</source>
        <translation>Mostra popup al passaggio del puntatore </translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="121"/>
        <source>Button style</source>
        <translation>Stile dei pulsanti</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="76"/>
        <source>Close on middle-click</source>
        <translation>Chiudi con un clic del tasto centrale</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="45"/>
        <source>Icon and text</source>
        <translation>Icone e testo</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="46"/>
        <source>Only icon</source>
        <translation>Solo icone</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="47"/>
        <source>Only text</source>
        <translation>Solo testo</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="49"/>
        <source>Current</source>
        <translation>attuale</translation>
    </message>
</context>
</TS>
